<?php
/*
Plugin Name: widget RuleTag
Plugin URI: http://www.gem-one.com/
Description: widgetに出力ルールを付与。配置した各widgetにルールタグを入力できるようにする。指定したタグに紐付けされた関数を自身のテーマ内に定義すると、当該関数がtrueで戻る場合にのみ、当該widgetが表示されるようになる。タグは半角カンマで複数指定可能。注意）タグは半角英数字('_'含む）のみで指定すること。
Version: 0.1
Author: gonzo/Gem-one
Author URI: http://blog.gem-one.com/gonzo/
*/

/*Create Action*/
$gemone_widget_ruletag_instance = new Gemone_WidgetRuleTag();

/*Gem-one widgetRuleTag Class---------------------*/
class Gemone_WidgetRuleTag 
{
	public function __construct()
	{
		add_action('init', array( $this,'action_init'));
	}

	/*-init-----------------*/
	public function action_init()
	{
		if ( is_admin() ) {
			add_action( 'in_widget_form', array( $this,'gemone_widgetTag_display' ), 10, 3 );
			add_filter( 'widget_update_callback', array( $this,'gemone_widgetTag_update') , 10, 3 );
			add_action( 'admin_enqueue_scripts', array( $this,'gemone_widgetTag_javascript'));
		} else {
			add_action( 'widget_display_callback', array( $this,'gemone_widgetTag_filter') );
		}
	}

	/*-Admin-----------------*/
	/*StyleSheet read*/
	public function gemone_widgetTag_javascript()
	{
		$purl = plugins_url();
		wp_enqueue_style( 'gemone_widgettag_css',$purl.'/gem-one.widgetTag/css/styles.css' );
	}

	public function gemone_widgetTag_selected( $flagA , $flagB )
	{
		if ( $flagA == $flagB ) return 'selected';
		return '';
	}

	public function gemone_widgetTag_display( $widget, $return, $instance )
	{
		/*widgetTag Text Data*/
		$conditions = ''; 

		/*widgetTag And/Or flag Data*/
		/* 0:AND  1:OR */
		$rules = 0;

		if ( isset( $instance['gemone_widgetTag'] ) )
			$conditions = $instance['gemone_widgetTag'];
		if ( isset( $instance['gemone_widgetTag_rule'] ) )
			$rules = $instance['gemone_widgetTag_rule'];

		/*output form of rule*/
?>
		<div class="gemone_widgetTag">Gem-one widgetRuleTag<br/>
			Tag:<input type="text"  name="gemone_widgettag" value="<?php echo $conditions;?>"/><br/>
			Rule:<select name="gemone_widgettag_rule" >
					<option value="0" <?php echo $this->gemone_widgetTag_selected($rules,0);?>>and</option>
					<option value="1" <?php echo $this->gemone_widgetTag_selected($rules,1);?>>or</option>
				 </select>
		</div>
		<?php
	}

	/*-Admin-----------------*/
	
	/*Widget Option Save*/
	public function gemone_widgetTag_update( $instance, $new_instance, $old_instance )
	{
		$instance['gemone_widgetTag']       = $_POST['gemone_widgettag'];
		$instance['gemone_widgetTag_rule'] = $_POST['gemone_widgettag_rule'];

		do_action( 'widget_conditions_save' );

		return $instance;
	
	}

	/*-View------------------*/
	public function gemone_widgetTag_filter( $instance )
	{
		$rules = 0;
		if ( empty( $instance['gemone_widgetTag'] ) )
			return $instance;
		if ( !empty( $instance['gemone_widgetTag_rule'] )) 
			$rules = $instance['gemone_widgetTag_rule'];

		$data = explode( ',' , $instance['gemone_widgetTag'] );
		$ret = $instance ;
		foreach( $data as $item ) {
			$f = trim(preg_replace( '/\W/','' , $item ));
			if ( function_exists( 'gemone_widgetTag_'.$f )) {
				$ret = call_user_func( 'gemone_widgetTag_'.$f , $ret );
				if ( $rules == 1 and  /*or設定で*/
					 $ret != null ) /*出力OKなら*/ {
					/*出力*/
					return $ret;
				}
				if ( $rules == 0 and /*and設定で*/
					 $ret == null ) /*出力NGなら*/ {
					return false;
				}
				if ( $ret == null )
					$ret = $instance;
			}
		}	
		return $ret;
	}
}

?>
